@@ -14,7 +14,7 @@
 
 """oslo.i18n integration module.
 
-See http://docs.openstack.org/developer/oslo.i18n/usage.html .
+See https://docs.openstack.org/oslo.i18n/latest/user/usage.html .
 
 """
 
@@ -35,16 +35,6 @@ _C = _translators.contextual_form
 # requires oslo.i18n >=2.1.0
 _P = _translators.plural_form
 
-# Translators for log levels.
-#
-# The abbreviated names are meant to reflect the usual use of a short
-# name like '_'. The "L" is for "log" and the other letter comes from
-# the level.
-_LI = _translators.log_info
-_LW = _translators.log_warning
-_LE = _translators.log_error
-_LC = _translators.log_critical
-
 
 def get_available_languages():
         return oslo_i18n.get_available_languages(DOMAIN)
