@@ -69,7 +69,7 @@ REQ_ID_HEADER = 'X-OpenStack-Request-ID'
 # tell keystoneclient that we can ignore the /v1|v2/{project_id} component of
 # the service catalog when doing discovery lookups
 for svc in ('volume', 'volumev2', 'volumev3'):
-    discover.add_catalog_discover_hack(svc, re.compile('/v[12]/\w+/?$'), '/')
+    discover.add_catalog_discover_hack(svc, re.compile(r'/v[12]/\w+/?$'), '/')
 
 
 def get_server_version(url):
@@ -210,7 +210,13 @@ class SessionClient(adapter.LegacyJsonAdapter):
 
     def _get_base_url(self):
         endpoint = self.get_endpoint()
-        base_url = '/'.join(endpoint.split('/')[:3]) + '/'
+        m = re.search('(.+)/v[1-3].*', endpoint)
+        if m:
+            # Get everything up until the version identifier
+            base_url = '%s/' % m.group(1)
+        else:
+            # Fall back to the root of the URL
+            base_url = '/'.join(endpoint.split('/')[:3]) + '/'
         return base_url
 
     def get_volume_api_version_from_endpoint(self):
