@@ -481,7 +481,7 @@ def do_reset_state(cs, args):
            type=int,
            action=CheckSizeArgForCreate,
            help='Size of volume, in GiBs. (Required unless '
-                'snapshot-id/source-volid is specified).')
+                'snapshot-id/source-volid/backup-id is specified).')
 @utils.arg('--consisgroup-id',
            metavar='<consistencygroup-id>',
            default=None,
@@ -560,7 +560,9 @@ def do_reset_state(cs, args):
            dest='scheduler_hints',
            action='append',
            default=[],
-           help='Scheduler hint, like in nova.')
+           help='Scheduler hint, similar to nova. Repeat option to set '
+                'multiple hints. Values with the same key will be stored '
+                'as a list.')
 @utils.arg('--allow-multiattach',
            dest='multiattach',
            action="store_true",
